@@ -35,8 +35,7 @@ main()
   gchar *result;
   gboolean success;
 
-  upload (NULL,
-          filename,
+  upload (filename,
 	  &success,
 	  &result,
 	  progress);
